import logging

from .oauth1_auth import OAuth1
from .oauth1_session import OAuth1Session
from .oauth2_auth import OAuth2
from .oauth2_session import OAuth2Session, TokenUpdated


__all__ = [
    "__version__",
    "OAuth2Session",
    "TokenUpdated",
]

__version__ = "0.0.5"

logging.getLogger("async_oauthlib").addHandler(logging.NullHandler())
